pub struct OpenIDClientOpts {
pub client_id: String,
pub client_secret: Option<Zeroizing<String>>,
pub redirect_uri: String,
pub validate_id_token_sig: bool,
pub accepted_audiences: Vec<String>,
pub validate_aud: bool,
pub validate_exp: bool,
pub validate_nbf: bool,
}Expand description
OpenID client options
Fields
client_id: StringThis client ID
client_secret: Option<Zeroizing<String>>This client secret
redirect_uri: StringRedirect URI to use when performing authentication requests
validate_id_token_sig: boolDisable id token signature & content check
accepted_audiences: Vec<String>Accepted audiences in JWT
validate_aud: boolWhether audience field of jwt should be validated or not
validate_exp: boolWhether expiration field of jwt should be validated or not
validate_nbf: boolWhether not before field of jwt should be validated or not
Implementations