AuthorizeQuery

Struct AuthorizeQuery 

pub struct AuthorizeQuery<'a> {
    pub scope: Cow<'a, str>,
    pub response_type: Cow<'a, str>,
    pub client_id: Cow<'a, str>,
    pub redirect_uri: Cow<'a, str>,
    pub state: Option<Cow<'a, str>>,
    pub response_mode: Option<Cow<'a, str>>,
    pub nonce: Option<Cow<'a, str>>,
    pub code_challenge: Option<Cow<'a, str>>,
    pub code_challenge_method: Option<Cow<'a, str>>,
}
OpenID Authorize query parameters

Fields

scope: Cow<'a, str>

REQUIRED. OpenID Connect requests MUST contain the openid scope value. If the openid scope value is not present, the behavior is entirely unspecified. Other scope values MAY be present. Scope values used that are not understood by an implementation SHOULD be ignored. See Sections 5.4 and 11 for additional scope values defined by this specification.

response_type: Cow<'a, str>

REQUIRED. OAuth 2.0 Response Type value that determines the authorization processing flow to be used, including what parameters are returned from the endpoints used. When using the Authorization Code Flow, this value is code.

client_id: Cow<'a, str>

REQUIRED. OAuth 2.0 Client Identifier valid at the Authorization Server.

redirect_uri: Cow<'a, str>

REQUIRED. Redirection URI to which the response will be sent. This URI MUST exactly match one of the Redirection URI values for the Client pre-registered at the OpenID Provider, with the matching performed as described in Section 6.2.1 of RFC3986 (Simple String Comparison). When using this flow, the Redirection URI SHOULD use the https scheme; however, it MAY use the http scheme, provided that the Client Type is confidential, as defined in Section 2.1 of OAuth 2.0, and provided the OP allows the use of http Redirection URIs in this case. The Redirection URI MAY use an alternate scheme, such as one that is intended to identify a callback into a native application.

state: Option<Cow<'a, str>>

RECOMMENDED. Opaque value used to maintain state between the request and the callback. Typically, Cross-Site Request Forgery (CSRF, XSRF) mitigation is done by cryptographically binding the value of this parameter with a browser cookie.

response_mode: Option<Cow<'a, str>>

OPTIONAL. Informs the Authorization Server of the mechanism to be used for returning parameters from the Authorization Endpoint. This use of this parameter is NOT RECOMMENDED when the Response Mode that would be requested is the default mode specified for the Response Type.

nonce: Option<Cow<'a, str>>

OPTIONAL. String value used to associate a Client session with an ID Token, and to mitigate replay attacks. The value is passed through unmodified from the Authentication Request to the ID Token. Sufficient entropy MUST be present in the nonce values used to prevent attackers from guessing values.

code_challenge: Option<Cow<'a, str>>code_challenge_method: Option<Cow<'a, str>>

OPTIONAL, defaults to “plain” if not present in the request. Code verifier transformation method is “S256” or “plain”.