OpenIDClient

Struct OpenIDClient 

pub struct OpenIDClient {
    pub config: OpenIDConfig,
    pub jwks: Option<JwkSet>,
    pub opts: OpenIDClientOpts,
}
OpenID client

Fields

config: OpenIDConfigjwks: Option<JwkSet>opts: OpenIDClientOpts

Implementations

Source

impl OpenIDClient

pub async fn new( config: OpenIDConfig, jwks: Option<JwkSet>, opts: &OpenIDClientOpts, ) -> Self

Construct an OpenID client by give hard-coded configuration values

pub async fn new_from_url( url: &str, opts: &OpenIDClientOpts, ) -> Result<Self, OpenIdError>

Construct an OpenID client by loading configuration from a given .well-known/openid-configuration URL

pub fn gen_authorization_url( &self, state: &str, code_challenge: Option<CodeChallenge>, ) -> String

Get the authorization URL where a user should be redirect to perform authentication

pub async fn request_token_from_code( &self, code: &str, code_verifier: Option<&str>, ) -> Result<(OpenIDTokenResponse, String), OpenIdError>

Query the token endpoint using an authorization code

pub async fn request_token_from_refresh_token( &self, refresh_token: &str, ) -> Result<(OpenIDTokenResponse, String), OpenIdError>

Query the token endpoint using a refresh token

pub fn verify_jwt<T: DeserializeOwned>( &self, jwt: &str, ) -> Result<TokenData<T>, OpenIdError>

Decode & verify a JWT signature

pub async fn request_user_info( &self, token: &OpenIDTokenResponse, ) -> Result<(OpenIDUserInfo, String), OpenIdError>

Query the UserInfo endpoint.

This endpoint should be used after having successfully retrieved the token

This endpoint returns both the parsed value and the raw response, in case of presence of additional fields